==> jc-1.4.0.tar.gz: javax/imageio/stream/IIOByteBuffer.h <==
// public class javax.imageio.stream.IIOByteBuffer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34535665ae4cefd8 javax_imageio_stream_IIOByteBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_stream_IIOByteBuffer_H_
#define _JC_javax_imageio_stream_IIOByteBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$sub_refs	_jc_javax_imageio_stream_IIOByteBuffer$sub_refs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs	_jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$refs	_jc_javax_imageio_stream_IIOByteBuffer$refs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$nonrefs	_jc_javax_imageio_stream_IIOByteBuffer$nonrefs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$object	_jc_javax_imageio_stream_IIOByteBuffer$object;

typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vmethods	_jc_javax_imageio_stream_IIOByteBuffer$vmethods;
typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vtable	_jc_javax_imageio_stream_IIOByteBuffer$vtable;
typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vtype	_jc_javax_imageio_stream_IIOByteBuffer$vtype;

// Constructors
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern _jc_byte_array *_jc_javax_imageio_stream_IIOByteBuffer$method$getData$3bcf99c3a6db9163(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
extern jint _jc_javax_imageio_stream_IIOByteBuffer$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
extern jint _jc_javax_imageio_stream_IIOByteBuffer$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setData$0edcebd40cefb56e(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *);
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setLength$1c9b2a0f8424f0fc(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint);
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setOffset$8f9bca0c1b25f322(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getData$3bcf99c3a6db9163;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setData$0edcebd40cefb56e;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setLength$1c9b2a0f8424f0fc;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setOffset$8f9bca0c1b25f322;

// Virtual methods structure
struct _jc_javax_imageio_stream_IIOByteBuffer$vmethods {
	_jc_byte_array	*(*getData$3bcf99c3a6db9163)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *);
	void	(*setData$0edcebd40cefb56e)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *);
	void	(*setLength$1c9b2a0f8424f0fc)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint);
	void	(*setOffset$8f9bca0c1b25f322)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint);
};

// Vtable
struct _jc_javax_imageio_stream_IIOByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_IIOByteBuffer$vmethods	javax_imageio_stream_IIOByteBuffer;
};

// Vtype
struct _jc_javax_imageio_stream_IIOByteBuffer$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_IIOByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_IIOByteBuffer$sub_refs {
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_IIOByteBuffer$refs {
    _jc_javax_imageio_stream_IIOByteBuffer$sub_refs	javax_imageio_stream_IIOByteBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs {
	jint	offset;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_IIOByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs	javax_imageio_stream_IIOByteBuffer;
};

// Object instance structure
struct _jc_javax_imageio_stream_IIOByteBuffer$object {
	_jc_javax_imageio_stream_IIOByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_IIOByteBuffer$vtype	*vtype;
	_jc_javax_imageio_stream_IIOByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_IIOByteBuffer$vtype _jc_javax_imageio_stream_IIOByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_IIOByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_IIOByteBuffer$class_object;

#endif	/* _JC_javax_imageio_stream_IIOByteBuffer_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/IIOByteBuffer.h <==
// public class javax.imageio.stream.IIOByteBuffer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34535665ae4cefd8 javax_imageio_stream_IIOByteBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_stream_IIOByteBuffer_H_
#define _JC_javax_imageio_stream_IIOByteBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$sub_refs	_jc_javax_imageio_stream_IIOByteBuffer$sub_refs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs	_jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$refs	_jc_javax_imageio_stream_IIOByteBuffer$refs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$nonrefs	_jc_javax_imageio_stream_IIOByteBuffer$nonrefs;
typedef struct _jc_javax_imageio_stream_IIOByteBuffer$object	_jc_javax_imageio_stream_IIOByteBuffer$object;

typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vmethods	_jc_javax_imageio_stream_IIOByteBuffer$vmethods;
typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vtable	_jc_javax_imageio_stream_IIOByteBuffer$vtable;
typedef const struct _jc_javax_imageio_stream_IIOByteBuffer$vtype	_jc_javax_imageio_stream_IIOByteBuffer$vtype;

// Constructors
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_javax_imageio_stream_IIOByteBuffer$method$getData$3bcf99c3a6db9163(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_IIOByteBuffer$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_IIOByteBuffer$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setData$0edcebd40cefb56e(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setLength$1c9b2a0f8424f0fc(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_IIOByteBuffer$method$setOffset$8f9bca0c1b25f322(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getData$3bcf99c3a6db9163;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$getOffset$520eb02cb0855546;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setData$0edcebd40cefb56e;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setLength$1c9b2a0f8424f0fc;
extern _jc_method _jc_javax_imageio_stream_IIOByteBuffer$method_info$setOffset$8f9bca0c1b25f322;

// Virtual methods structure
struct _jc_javax_imageio_stream_IIOByteBuffer$vmethods {
	_jc_byte_array	*(*getData$3bcf99c3a6db9163)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*setData$0edcebd40cefb56e)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*setLength$1c9b2a0f8424f0fc)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint) _JC_JCNI_ATTR;
	void	(*setOffset$8f9bca0c1b25f322)(_jc_env *, struct _jc_javax_imageio_stream_IIOByteBuffer$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_IIOByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_IIOByteBuffer$vmethods	javax_imageio_stream_IIOByteBuffer;
};

// Vtype
struct _jc_javax_imageio_stream_IIOByteBuffer$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_IIOByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_IIOByteBuffer$sub_refs {
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_IIOByteBuffer$refs {
    _jc_javax_imageio_stream_IIOByteBuffer$sub_refs	javax_imageio_stream_IIOByteBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs {
	jint	offset;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_IIOByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_IIOByteBuffer$sub_nonrefs	javax_imageio_stream_IIOByteBuffer;
};

// Object instance structure
struct _jc_javax_imageio_stream_IIOByteBuffer$object {
	_jc_javax_imageio_stream_IIOByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_IIOByteBuffer$vtype	*vtype;
	_jc_javax_imageio_stream_IIOByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_IIOByteBuffer$vtype _jc_javax_imageio_stream_IIOByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_IIOByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_IIOByteBuffer$class_object;

#endif	/* _JC_javax_imageio_stream_IIOByteBuffer_H_ */
